# Flask Template for a Extension

[![GitHub issues](https://img.shields.io/github/issues/juniors90/Flask-NameExtension)](https://github.com/juniors90/Flask-NameExtension/issues)
[![GitHub forks](https://img.shields.io/github/forks/juniors90/Flask-NameExtension)](https://github.com/juniors90/Flask-NameExtension/network)
[![GitHub stars](https://img.shields.io/github/stars/juniors90/Flask-NameExtension)](https://github.com/juniors90/Flask-NameExtension/stargazers)
[![GitHub license](https://img.shields.io/github/license/juniors90/Flask-NameExtension)](https://github.com/juniors90/Flask-NameExtension/blob/main/LICENSE)
[![GitHub contributors](https://img.shields.io/github/contributors/juniors90/Flask-NameExtension?color=green)](https://github.com/juniors90/Flask-NameExtension/graphs/contributors)
![docstr-cov](https://img.shields.io/endpoint?url=https://jsonbin.org/juniors90/Flask-NameExtension/badges/docstr-cov)
[![black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
